aboutsummaryrefslogtreecommitdiffstats
path: root/vendor/github.com/blevesearch/bleve/mapping/mapping.go
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/github.com/blevesearch/bleve/mapping/mapping.go')
-rw-r--r--vendor/github.com/blevesearch/bleve/mapping/mapping.go13
1 files changed, 11 insertions, 2 deletions
diff --git a/vendor/github.com/blevesearch/bleve/mapping/mapping.go b/vendor/github.com/blevesearch/bleve/mapping/mapping.go
index 610021101f..4a47281126 100644
--- a/vendor/github.com/blevesearch/bleve/mapping/mapping.go
+++ b/vendor/github.com/blevesearch/bleve/mapping/mapping.go
@@ -22,12 +22,21 @@ import (
"github.com/blevesearch/bleve/document"
)
// A Classifier is an interface describing any object
// which knows how to identify its own type.
type Classifier interface {
Type() string
}
+// A bleveClassifier is an interface describing any object which knows how
+// to identify its own type. This is introduced as an alternative to the
+// Classifier interface which often has naming conflicts with existing
+// structures.
+type bleveClassifier interface {
+ BleveType() string
+}
+
var logger = log.New(ioutil.Discard, "bleve mapping ", log.LstdFlags)
// SetLog sets the logger used for logging
@@ -22,12 +22,21 @@ import (
"github.com/blevesearch/bleve/document"
)
-// A Classifier is an interface describing any object
-// which knows how to identify its own type.
+// A Classifier is an interface describing any object which knows how to
+// identify its own type. Alternatively, if a struct already has a Type
+// field or method in conflict, one can use BleveType instead.
type Classifier interface {
Type() string